# gdsfactory Generic PDK

## Usage

To be able to use KLayout Technology, you need to do the following steps:

- Define some environment variables

```bash
    export PDK_ROOT=<path to this generic tech>
    export KLAYOUT_HOME="$PDK_ROOT/klayout"
```

- Open klayout using the following command

```bash
    klayout -e -j $KLAYOUT_HOME -l $KLAYOUT_HOME/tech/layers.lyp -nn $KLAYOUT_HOME/tech/generic_tech.lyt
```

Or you could use `generic_tech.sh` script in this directory:

```bash
    bash generic_tech.sh
```

## Klayout Net tracing

You could trace your nets using klayout net tracer after loading your generic tech.

- After opening your layout, from Tools menu, select Trace Net.

As shown, you need to click on Trace Net and select from layout your desired net that you want to trace.

![image](https://user-images.githubusercontent.com/91015308/236182447-3c9f4fb9-9c0f-4c2e-9016-653cd112464f.png)
![image](https://user-images.githubusercontent.com/91015308/236182554-c368d277-8fff-4358-8cf5-d3a8d21bbb08.png)
